@@ -36,19 +36,13 @@ enum ErrorCodes
     KLispErrNotAnInFixOperator    ,
     KLispErrUser                  ,
     KLispErrIsNotInFix            ,
-    KLispErrSecurityBreach         ,
+    KLispErrSecurityBreach        ,
+    KLispErrLibraryNotFound       ,
+    KLispErrUserInterrupt         ,
+    KLispErrNonBooleanPredicateInPattern,
     KLispNrErrors
 };
 
-/*TODO
-class LispException
-{
-public:
-    LispException(LispCharPtr aString)
-        : iString(aString) {};
-    LispString iString;
-};
-*/
 
 
 inline void Check(LispBoolean hastobetrue, LispInt aError)
@@ -60,6 +54,5 @@ inline void Check(LispBoolean hastobetrue, LispInt aError)
 
 
 
-
 #endif
 
