@@ -2,6 +2,7 @@
 #ifndef __mathcommands_h__
 #define __mathcommands_h__
 
+#include "yacasbase.h"
 #include "lispenvironment.h"
 #include "lispevalhash.h"
 #include "lispobject.h"
@@ -21,10 +22,6 @@ void LispEval(LispEnvironment& aEnvironment,LispPtr& aResult,
 //
 void LispWrite(LispEnvironment& aEnvironment, LispPtr& aResult,
                   LispPtr& aArguments);
-void LispSpace(LispEnvironment& aEnvironment, LispPtr& aResult,
-                  LispPtr& aArguments);
-void LispNewLine(LispEnvironment& aEnvironment, LispPtr& aResult,
-                  LispPtr& aArguments);
 void LispWriteString(LispEnvironment& aEnvironment, LispPtr& aResult,
                   LispPtr& aArguments);
 void LispFullForm(LispEnvironment& aEnvironment, LispPtr& aResult,
@@ -87,6 +84,8 @@ void LispConcatenate(LispEnvironment& aEnvironment, LispPtr& aResult,
               LispPtr& aArguments);
 void LispConcatenateStrings(LispEnvironment& aEnvironment, LispPtr& aResult,
               LispPtr& aArguments);
+void LispNoCacheConcatenateStrings(LispEnvironment& aEnvironment, LispPtr& aResult,
+              LispPtr& aArguments);
 void LispDelete(LispEnvironment& aEnvironment, LispPtr& aResult,
                   LispPtr& aArguments);
 void LispInsert(LispEnvironment& aEnvironment, LispPtr& aResult,
@@ -134,6 +133,11 @@ void LispRuleBase(LispEnvironment& aEnvironment, LispPtr& aResult,
                   LispPtr& aArguments);
 void LispMacroRuleBase(LispEnvironment& aEnvironment, LispPtr& aResult,
                        LispPtr& aArguments);
+void LispRuleBaseListed(LispEnvironment& aEnvironment, LispPtr& aResult,
+                  LispPtr& aArguments);
+void LispMacroRuleBaseListed(LispEnvironment& aEnvironment, LispPtr& aResult,
+                             LispPtr& aArguments);
+
 void LispHoldArg(LispEnvironment& aEnvironment, LispPtr& aResult,
                   LispPtr& aArguments);
 void LispNewRule(LispEnvironment& aEnvironment, LispPtr& aResult,
@@ -142,7 +146,7 @@ void LispMacroNewRule(LispEnvironment& aEnvironment, LispPtr& aResult,
                   LispPtr& aArguments);
 void LispUnFence(LispEnvironment& aEnvironment, LispPtr& aResult,
                   LispPtr& aArguments);
-void LispTryRetract(LispEnvironment& aEnvironment, LispPtr& aResult,
+void LispRetract(LispEnvironment& aEnvironment, LispPtr& aResult,
                  LispPtr& aArguments);
 
 //
@@ -287,6 +291,8 @@ void LispRightPrecedence(LispEnvironment& aEnvironment, LispPtr& aResult,
                           LispPtr& aArguments);
 
 
+void LispIsBodied(LispEnvironment& aEnvironment, LispPtr& aResult,
+               LispPtr& aArguments);
 void LispIsInFix(LispEnvironment& aEnvironment, LispPtr& aResult,
                LispPtr& aArguments);
 void LispIsPreFix(LispEnvironment& aEnvironment, LispPtr& aResult,
@@ -335,6 +341,7 @@ void GenArraySet(LispEnvironment& aEnvironment,LispPtr& aResult,
 
 void LispTrace(LispEnvironment& aEnvironment,LispPtr& aResult, LispPtr& aArguments);
 void LispTraceRule(LispEnvironment& aEnvironment,LispPtr& aResult, LispPtr& aArguments);
+void LispTraceStack(LispEnvironment& aEnvironment,LispPtr& aResult, LispPtr& aArguments);
 
 void LispReadLisp(LispEnvironment& aEnvironment, LispPtr& aResult,
                   LispPtr& aArguments);
@@ -354,10 +361,82 @@ void GenPatternMatches(LispEnvironment& aEnvironment,LispPtr& aResult,
 
 void LispRuleBaseDefined(LispEnvironment& aEnvironment,LispPtr& aResult,
                          LispPtr& aArguments);
+void LispDefLoadFunction(LispEnvironment& aEnvironment,LispPtr& aResult,
+                         LispPtr& aArguments);
 void LispRuleBaseArgList(LispEnvironment& aEnvironment,LispPtr& aResult,
                          LispPtr& aArguments);
 
 
+void LispNewRulePattern(LispEnvironment& aEnvironment, LispPtr& aResult,
+                        LispPtr& aArguments);
+void LispMacroNewRulePattern(LispEnvironment& aEnvironment, LispPtr& aResult,
+                  LispPtr& aArguments);
+
+
+void LispSubst(LispEnvironment& aEnvironment, LispPtr& aResult,
+               LispPtr& aArguments);
+void LispLocalSymbols(LispEnvironment& aEnvironment, LispPtr& aResult,
+                      LispPtr& aArguments);
+
+
+void LispFac(LispEnvironment& aEnvironment, LispPtr& aResult,
+                  LispPtr& aArguments);
+
+void LispApplyPure(LispEnvironment& aEnvironment, LispPtr& aResult,
+                   LispPtr& aArguments);
+
+void LispPrettyPrinter(LispEnvironment& aEnvironment, LispPtr& aResult,
+                       LispPtr& aArguments);
+
+
+void LispGarbageCollect(LispEnvironment& aEnvironment, LispPtr& aResult,
+                        LispPtr& aArguments);
+
+void LispLazyGlobal(LispEnvironment& aEnvironment, LispPtr& aResult,
+                    LispPtr& aArguments);
+
+void LispPatchLoad(LispEnvironment& aEnvironment, LispPtr& aResult,
+                   LispPtr& aArguments);
+void LispPatchString(LispEnvironment& aEnvironment, LispPtr& aResult,
+                     LispPtr& aArguments);
+
+void LispDllLoad(LispEnvironment& aEnvironment, LispPtr& aResult,
+                 LispPtr& aArguments);
+void LispDllUnload(LispEnvironment& aEnvironment, LispPtr& aResult,
+                   LispPtr& aArguments);
+void LispDllEnumerate(LispEnvironment& aEnvironment, LispPtr& aResult,
+                      LispPtr& aArguments);
+
+void LispSetExtraInfo(LispEnvironment& aEnvironment, LispPtr& aResult,
+                   LispPtr& aArguments);
+void LispGetExtraInfo(LispEnvironment& aEnvironment, LispPtr& aResult,
+                   LispPtr& aArguments);
+
+
+void LispBerlekamp(LispEnvironment& aEnvironment, LispPtr& aResult,
+                   LispPtr& aArguments);
+
+void LispDefaultTokenizer(LispEnvironment& aEnvironment, LispPtr& aResult,
+                   LispPtr& aArguments);
+void LispCTokenizer(LispEnvironment& aEnvironment, LispPtr& aResult,
+                   LispPtr& aArguments);
+void LispXmlTokenizer(LispEnvironment& aEnvironment, LispPtr& aResult,
+                      LispPtr& aArguments);
+
+void LispExplodeTag(LispEnvironment& aEnvironment, LispPtr& aResult,
+                    LispPtr& aArguments);
+
+void LispFastAssoc(LispEnvironment& aEnvironment, LispPtr& aResult,
+                   LispPtr& aArguments);
+
+void LispCurrentFile(LispEnvironment& aEnvironment, LispPtr& aResult,
+                     LispPtr& aArguments);
+void LispCurrentLine(LispEnvironment& aEnvironment, LispPtr& aResult,
+                     LispPtr& aArguments);
+
+void LispBackQuote(LispEnvironment& aEnvironment, LispPtr& aResult,
+                     LispPtr& aArguments);
+
 #endif
 
 
