@@ -22,12 +22,14 @@ public:
 class StdFileInput : public LispInput
 {
 public:
-    StdFileInput(LispLocalFile& aFile);
+    StdFileInput(LispLocalFile& aFile,InputStatus& aStatus);
     ~StdFileInput();
     virtual LispChar Next();
     virtual LispChar Peek();
     virtual LispBoolean EndOfStream();
     void Rewind();
+    virtual LispCharPtr StartPtr();
+    virtual LispInt Position();
 protected:
     RFile &iFile;
     LispCharPtr iBuffer;
@@ -58,15 +60,19 @@ public:
 
 
 // Epoc input : for now none...
-class StdUserInput : public LispInput
+class CachedStdUserInput : public LispInput
 {
 public:
-    StdUserInput();
+    CachedStdUserInput(InputStatus& aStatus);
     virtual LispChar Next();
     virtual LispChar Peek();
     virtual LispBoolean EndOfStream();
+    virtual LispCharPtr StartPtr();
+    virtual LispInt Position();
 };
 
+void InternalFindFile(LispCharPtr aFileName, InputDirectories& aInputDirectories,
+                     LispCharPtr aFoundFile);
 
 
 
